@@ -6,15 +6,14 @@
  *
  * This is mainly useful for debugging purposes.
  *
- * @copyright Copyright (C) 2009-2014 fruux GmbH. All rights reserved.
+ * @copyright Copyright (C) 2009-2015 fruux GmbH (https://fruux.com/).
  * @author Evert Pot (http://evertpot.com/)
- * @license http://code.google.com/p/sabredav/wiki/License Modified BSD License
+ * @license http://sabre.io/license/ Modified BSD License
  */
 
 use
     Sabre\HTTP\Request,
-    Sabre\HTTP\Response,
-    Sabre\HTTP\Client;
+    Sabre\HTTP\Response;
 
 
 // Find the autoloader
